@@ -1,20 +1,18 @@
 /*
  *   Copyright 2013 Martin Gräßlin <mgraesslin@kde.org>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
+ *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *   You should have received a copy of the GNU Lesser General Public
+ *   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 #include "nettesthelper.h"
 #include "kwindowsystem.h"
@@ -46,13 +44,12 @@ private Q_SLOTS:
     void testWorkAreaChanged();
     void testWindowTitleChanged();
     void testMinimizeWindow();
+    void testPlatformX11();
 };
 
 void KWindowSystemX11Test::initTestCase()
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 3, 0)
     QCoreApplication::setAttribute(Qt::AA_ForceRasterWidgets);
-#endif
 }
 
 void KWindowSystemX11Test::testActiveWindowChanged()
@@ -387,6 +384,13 @@ void KWindowSystemX11Test::testMinimizeWindow()
     QVERIFY(!info3.isMinimized());
 }
 
+void KWindowSystemX11Test::testPlatformX11()
+{
+    QCOMPARE(KWindowSystem::platform(), KWindowSystem::Platform::X11);
+    QCOMPARE(KWindowSystem::isPlatformX11(), true);
+    QCOMPARE(KWindowSystem::isPlatformWayland(), false);
+}
+
 QTEST_MAIN(KWindowSystemX11Test)
 
 #include "kwindowsystemx11test.moc"
